# Theatre

> In the face of ambiguity, refuse the temptation to guess.

Finally, the music/video player API you've been waiting for!

This module *had* to be built because other music player APIs in python weren't multi-tasking,
easy to use, fast and lightweight (at the same time).

(It's a wrapper over MPV's json ipc interface.) 

This module can be used from multiple Processes/Threads (even across machines) thanks to ZProc.

---

[🐍🏕️](http://www.pycampers.com/)
